gocept.runner
=============

Create stand alone programs with full a Zope3 runtime environment.
These programs can be used either as one time run scripts or can be
automatically called after a defined period of time.

.. contents::
